# coding: utf-8

"""
    Weheat Backend

    This is the backend for the Weheat project

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional, Union
from pydantic import BaseModel, StrictFloat, StrictInt, StrictStr
from pydantic import Field
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class TotalEnergyAggregate(BaseModel):
    """
    TotalEnergyAggregate
    """ # noqa: E501
    heat_pump_id: Optional[StrictStr] = Field(default=None, alias="heatPumpId")
    total_ein_heating: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalEInHeating")
    total_ein_standby: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalEInStandby")
    total_ein_dhw: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalEInDhw")
    total_ein_heating_defrost: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalEInHeatingDefrost")
    total_ein_dhw_defrost: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalEInDhwDefrost")
    total_ein_cooling: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalEInCooling")
    total_e_out_heating: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalEOutHeating")
    total_e_out_dhw: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalEOutDhw")
    total_e_out_heating_defrost: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalEOutHeatingDefrost")
    total_e_out_dhw_defrost: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalEOutDhwDefrost")
    total_e_out_cooling: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalEOutCooling")
    __properties: ClassVar[List[str]] = ["heatPumpId", "totalEInHeating", "totalEInStandby", "totalEInDhw", "totalEInHeatingDefrost", "totalEInDhwDefrost", "totalEInCooling", "totalEOutHeating", "totalEOutDhw", "totalEOutHeatingDefrost", "totalEOutDhwDefrost", "totalEOutCooling",]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TotalEnergyAggregate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of TotalEnergyAggregate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "heatPumpId": obj.get("heatPumpId"),
            "totalEInHeating": obj.get("totalEInHeating"),
            "totalEInStandby": obj.get("totalEInStandby"),
            "totalEInDhw": obj.get("totalEInDhw"),
            "totalEInHeatingDefrost": obj.get("totalEInHeatingDefrost"),
            "totalEInDhwDefrost": obj.get("totalEInDhwDefrost"),
            "totalEInCooling": obj.get("totalEInCooling"),
            "totalEOutHeating": obj.get("totalEOutHeating"),
            "totalEOutDhw": obj.get("totalEOutDhw"),
            "totalEOutHeatingDefrost": obj.get("totalEOutHeatingDefrost"),
            "totalEOutDhwDefrost": obj.get("totalEOutDhwDefrost"),
            "totalEOutCooling": obj.get("totalEOutCooling")
        })
        return _obj


